@@ -103,14 +103,14 @@ class Application:
     def add_json_api_routes(self):
         """Add JSON API routes to the web application."""
 
-        path = r'/{collection:[^/]*}'
+        path = r'/resources/{collection:[^/]*}'
         self.app.add_routes([
             web.get(path, get_collection),
             web.post(path, post_collection),
             web.options(path, options_collection),
         ])
 
-        path = r'/{collection:[^/]*}/{id:[0-9A-Fa-f-]*}'
+        path = r'/resources/{collection:[^/]*}/{id:[0-9A-Fa-f-]*}'
         self.app.add_routes([
             web.get(path, get_object),
             web.delete(path, delete_object),
@@ -118,7 +118,7 @@ class Application:
             web.options(path, options_object),
         ])
 
-        path = (r'/{collection:[^/]*}/{id:[0-9A-Fa-f-]*}/'
+        path = (r'/resources/{collection:[^/]*}/{id:[0-9A-Fa-f-]*}/'
                 r'relationships/{relationship:[^/]*}')
         self.app.add_routes([
             web.get(path, get_relationship),
@@ -129,7 +129,7 @@ class Application:
             web.options(path, options_relationship),
         ])
 
-        path = (r'/{collection:[^/]*}/{id:[0-9A-Fa-f-]*}/'
+        path = (r'/resources/{collection:[^/]*}/{id:[0-9A-Fa-f-]*}/'
                 r'{related_resource:[^/]*}')
         self.app.add_routes([
             web.get(path, get_related_resource),
@@ -139,7 +139,7 @@ class Application:
     def add_event_socket_route(self):
         """Add event socket."""
 
-        path = '/event-socket/'
+        path = '/events'
         self.app.add_routes([
             web.get(path, self.get_event_socket),
         ])
