@@ -111,6 +111,27 @@ class QueryParameterUnsupportedError(Error):
         }
 
 
+class QueryParameterDuplicateError(Error):
+    """Errors related to duplicate identical query parameter keys in a
+    request."""
+
+    # pylint: disable=too-few-public-methods
+
+    status = 400
+
+    def __init__(self, parameter):
+        self.parameter = parameter
+
+    def to_error(self):
+        return {
+            'status': '400',
+            'source': {
+                'parameter': self.parameter,
+            },
+            'title': 'More than one parameter with the same key.',
+        }
+
+
 class IncludeInvalidPathError(Error):
     """Errors related to an invalid include relationship path."""
 
