@@ -44,25 +44,22 @@ def parse(request):
     # Servers MUST respond with a '415 Unsupported Media Type' status code if
     # a request specifies the header 'Content-Type: application/vnd.api+json'
     # with any media type parameters.
-    try:
-        content_type = headers['Content-Type']
+    for content_type in headers.getall('Content-Type', []):
         media_type, *parameters = content_type.split(';')
-        if media_type != 'application/vnd.api+json' or parameters:
+        if media_type == 'application/vnd.api+json' and parameters:
             errors.append(UnsupportedMediaTypeError())
-    except KeyError:
-        pass
 
     # [https://jsonapi.org/format/#content-negotiation-servers]
     # Servers MUST respond with a '406 Not Acceptable' status code if a
     # request's 'Accept' header contains the JSON API media type and all
     # instances of that media type are modified with media type parameters.
-    accept = headers['Accept']  # aiohttp provides default Accept header
     json_api_params = []
-    accept_values = accept.split(',')
-    for accept_value in accept_values:
-        media_range, *accept_params = accept_value.split(';')
-        if media_range == 'application/vnd.api+json':
-            json_api_params.append(accept_params)
+    for accept in headers.getall('Accept', []):
+        accept_values = accept.split(',')
+        for accept_value in accept_values:
+            media_range, *accept_params = accept_value.split(';')
+            if media_range == 'application/vnd.api+json':
+                json_api_params.append(accept_params)
     if json_api_params != [] and [] not in json_api_params:
         errors.append(NotAcceptableError())
 
