@@ -27,6 +27,8 @@ from urllib.parse import unquote
 
 from ajsonapi.conversions import id_name_to_number
 
+Now = 'CuRrEnT_TiMeStAmP'  # pylint:disable=invalid-name
+
 
 class Type:
     """Abstract base class for supported database types."""
@@ -87,6 +89,8 @@ class DateTime(Type):
 
     @staticmethod
     def sql(value):
+        if value == Now:
+            return 'current_timestamp'
         return f"'{value.isoformat()}'"
 
     @staticmethod
@@ -109,6 +113,8 @@ class DateTimeTZ(Type):
 
     @staticmethod
     def sql(value):
+        if value == Now:
+            return 'current_timestamp'
         return f"'{value.isoformat()}'"
 
     @staticmethod
