@@ -440,43 +440,43 @@ class Collection(Resource):
         that object):
 
         {
-            1: {
-                'type': 'centers',
-                'id': '1',
-                'attributes': {
-                    'attr_int': 1,
-                    'attr_str': 'one',
-                },
-                'relationships': {
-                    'one_one_local': {
-                        'data': {
-                            'type': 'one_one_locals',
-                            'id': UUID_11,
-                        },
-                        'links': {
-                            'self': '/centers/1/relationships/one_one_local',
-                            'related': '/centers/1/one_one_local',
-                        },
-                    },
-                    'many_one': {
-                        'data': {
-                            'type': 'many_ones',
-                            'id': UUID_31,
-                        },
-                        'links': {
-                            'self': '/centers/1/relationships/many_ones',
-                            'related': '/centers/1/many_ones',
-                        },
-                    },
+          1: {
+            'type': 'centers',
+            'id': '1',
+            'attributes': {
+              'attr_int': 1,
+              'attr_str': 'one',
+            },
+            'relationships': {
+              'one_one_local': {
+                'data': {
+                  'type': 'one_one_locals',
+                  'id': UUID_11,
                 },
                 'links': {
-                    'self': '/centers/1',
+                  'self': '/resources/centers/1/relationships/one_one_local',
+                  'related': '/resources/centers/1/one_one_local',
                 },
+              },
+              'many_one': {
+                'data': {
+                  'type': 'many_ones',
+                  'id': UUID_31,
+                },
+                'links': {
+                  'self': '/resources/centers/1/relationships/many_ones',
+                  'related': '/resources/centers/1/many_ones',
+                },
+              },
             },
-            2: {
-                ...,
+            'links': {
+              'self': '/resources/centers/1',
             },
-            ...
+          },
+          2: {
+            ...,
+          },
+          ...
         }
         """
         fields = env.query['fields']
@@ -583,9 +583,9 @@ class Collection(Resource):
                 relationships[rel.name] = {
                     'data': relationship_data,
                     'links': {
-                        'self': (f'/{self.name}/{id_name}/'
+                        'self': (f'/resources/{self.name}/{id_name}/'
                                  f'relationships/{rel.name}'),
-                        'related': (f'/{self.name}/{id_name}/'
+                        'related': (f'/resources/{self.name}/{id_name}/'
                                     f'{rel.name}'),
                     }
                 }
@@ -602,7 +602,7 @@ class Collection(Resource):
     def path(self):
         """Creates the path to the collection."""
 
-        return f'/{self.name}'
+        return f'/resources/{self.name}'
 
 
 class GetCollectionEnvironment:
@@ -763,11 +763,10 @@ class PostCollectionEnvironment:
         """Executes the POST /{collection} tasks."""
         async with self.collection.table.pool.acquire() as self.connection:
             async with self.connection.transaction():
+                self.create_tasks()
+                self.gather_future = gather(*self.tasks)
                 try:
-                    async with self.connection.transaction():
-                        self.create_tasks()
-                        self.gather_future = gather(*self.tasks)
-                        await self.gather_future
+                    await self.gather_future
                 except NonexistentRelationshipIdError:
                     env = VerifyRelationshipIdsEnvironment(
                         self.collection.table, self.relationships,
@@ -882,5 +881,5 @@ def parse_collection(request):
     try:
         return Collection.by_name[collection_name]
     except KeyError as exc:
-        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')
-                              ]) from exc
+        raise ErrorsException(
+            [ResourceNotFoundError(f'/resources/{collection_name}')]) from exc
